# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'signaldetails.ui',
# licensing of 'signaldetails.ui' applies.
#
# Created: Sun Nov  3 00:30:06 2019
#      by: pyside2-uic  running on PySide2 5.13.1
#
# WARNING! All changes made in this file will be lost!

from PySide2 import QtCore, QtGui, QtWidgets


class Ui_SignalDetails(object):
    def setupUi(self, SignalDetails):
        SignalDetails.setObjectName("SignalDetails")
        SignalDetails.resize(473, 580)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(SignalDetails)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.groupBox = QtWidgets.QGroupBox(SignalDetails)
        self.groupBox.setObjectName("groupBox")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.groupBox)
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout_14 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_14.setObjectName("horizontalLayout_14")
        self.nameLabel = QtWidgets.QLabel(self.groupBox)
        self.nameLabel.setObjectName("nameLabel")
        self.horizontalLayout_14.addWidget(self.nameLabel)
        self.nameEdit = QtWidgets.QLineEdit(self.groupBox)
        self.nameEdit.setObjectName("nameEdit")
        self.horizontalLayout_14.addWidget(self.nameEdit)
        self.verticalLayout.addLayout(self.horizontalLayout_14)
        self.horizontalLayout_13 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_13.setObjectName("horizontalLayout_13")
        self.commentLabel = QtWidgets.QLabel(self.groupBox)
        self.commentLabel.setObjectName("commentLabel")
        self.horizontalLayout_13.addWidget(self.commentLabel)
        self.commentEdit = QtWidgets.QLineEdit(self.groupBox)
        self.commentEdit.setObjectName("commentEdit")
        self.horizontalLayout_13.addWidget(self.commentEdit)
        self.verticalLayout.addLayout(self.horizontalLayout_13)
        self.horizontalLayout_12 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_12.setObjectName("horizontalLayout_12")
        self.startLabel = QtWidgets.QLabel(self.groupBox)
        self.startLabel.setObjectName("startLabel")
        self.horizontalLayout_12.addWidget(self.startLabel)
        self.startEdit = QtWidgets.QLineEdit(self.groupBox)
        self.startEdit.setObjectName("startEdit")
        self.horizontalLayout_12.addWidget(self.startEdit)
        self.verticalLayout.addLayout(self.horizontalLayout_12)
        self.horizontalLayout_11 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_11.setObjectName("horizontalLayout_11")
        self.lengthLabel = QtWidgets.QLabel(self.groupBox)
        self.lengthLabel.setObjectName("lengthLabel")
        self.horizontalLayout_11.addWidget(self.lengthLabel)
        self.lengthEdit = QtWidgets.QLineEdit(self.groupBox)
        self.lengthEdit.setObjectName("lengthEdit")
        self.horizontalLayout_11.addWidget(self.lengthEdit)
        self.verticalLayout.addLayout(self.horizontalLayout_11)
        self.horizontalLayout_9 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_9.setObjectName("horizontalLayout_9")
        self.typeLabel = QtWidgets.QLabel(self.groupBox)
        self.typeLabel.setObjectName("typeLabel")
        self.horizontalLayout_9.addWidget(self.typeLabel)
        self.typeEdit = QtWidgets.QLineEdit(self.groupBox)
        self.typeEdit.setObjectName("typeEdit")
        self.horizontalLayout_9.addWidget(self.typeEdit)
        self.verticalLayout.addLayout(self.horizontalLayout_9)
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_8.setObjectName("horizontalLayout_8")
        self.unitLabel = QtWidgets.QLabel(self.groupBox)
        self.unitLabel.setObjectName("unitLabel")
        self.horizontalLayout_8.addWidget(self.unitLabel)
        self.unitEdit = QtWidgets.QLineEdit(self.groupBox)
        self.unitEdit.setObjectName("unitEdit")
        self.horizontalLayout_8.addWidget(self.unitEdit)
        self.verticalLayout.addLayout(self.horizontalLayout_8)
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.minValueLabel = QtWidgets.QLabel(self.groupBox)
        self.minValueLabel.setObjectName("minValueLabel")
        self.horizontalLayout_7.addWidget(self.minValueLabel)
        self.minValueEdit = QtWidgets.QLineEdit(self.groupBox)
        self.minValueEdit.setObjectName("minValueEdit")
        self.horizontalLayout_7.addWidget(self.minValueEdit)
        self.verticalLayout.addLayout(self.horizontalLayout_7)
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.maxValueLabel = QtWidgets.QLabel(self.groupBox)
        self.maxValueLabel.setObjectName("maxValueLabel")
        self.horizontalLayout_6.addWidget(self.maxValueLabel)
        self.maxValueEdit = QtWidgets.QLineEdit(self.groupBox)
        self.maxValueEdit.setObjectName("maxValueEdit")
        self.horizontalLayout_6.addWidget(self.maxValueEdit)
        self.verticalLayout.addLayout(self.horizontalLayout_6)
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.muxLabel = QtWidgets.QLabel(self.groupBox)
        self.muxLabel.setObjectName("muxLabel")
        self.horizontalLayout_5.addWidget(self.muxLabel)
        self.muxEdit = QtWidgets.QLineEdit(self.groupBox)
        self.muxEdit.setObjectName("muxEdit")
        self.horizontalLayout_5.addWidget(self.muxEdit)
        self.verticalLayout.addLayout(self.horizontalLayout_5)
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.muxCountLabel = QtWidgets.QLabel(self.groupBox)
        self.muxCountLabel.setObjectName("muxCountLabel")
        self.horizontalLayout_4.addWidget(self.muxCountLabel)
        self.muxCountEdit = QtWidgets.QLineEdit(self.groupBox)
        self.muxCountEdit.setObjectName("muxCountEdit")
        self.horizontalLayout_4.addWidget(self.muxCountEdit)
        self.verticalLayout.addLayout(self.horizontalLayout_4)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.byteOrderLabel = QtWidgets.QLabel(self.groupBox)
        self.byteOrderLabel.setObjectName("byteOrderLabel")
        self.horizontalLayout_3.addWidget(self.byteOrderLabel)
        self.byteOrderEdit = QtWidgets.QLineEdit(self.groupBox)
        self.byteOrderEdit.setObjectName("byteOrderEdit")
        self.horizontalLayout_3.addWidget(self.byteOrderEdit)
        self.verticalLayout.addLayout(self.horizontalLayout_3)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.scaleLabel = QtWidgets.QLabel(self.groupBox)
        self.scaleLabel.setObjectName("scaleLabel")
        self.horizontalLayout_2.addWidget(self.scaleLabel)
        self.scaleEdit = QtWidgets.QLineEdit(self.groupBox)
        self.scaleEdit.setObjectName("scaleEdit")
        self.horizontalLayout_2.addWidget(self.scaleEdit)
        self.verticalLayout.addLayout(self.horizontalLayout_2)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.offsetLabel = QtWidgets.QLabel(self.groupBox)
        self.offsetLabel.setObjectName("offsetLabel")
        self.horizontalLayout.addWidget(self.offsetLabel)
        self.offsetEdit = QtWidgets.QLineEdit(self.groupBox)
        self.offsetEdit.setObjectName("offsetEdit")
        self.horizontalLayout.addWidget(self.offsetEdit)
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.horizontalLayout_10 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_10.setObjectName("horizontalLayout_10")
        self.saveSignal = QtWidgets.QPushButton(self.groupBox)
        self.saveSignal.setObjectName("saveSignal")
        self.horizontalLayout_10.addWidget(self.saveSignal)
        self.signalDeleteButton = QtWidgets.QPushButton(self.groupBox)
        self.signalDeleteButton.setObjectName("signalDeleteButton")
        self.horizontalLayout_10.addWidget(self.signalDeleteButton)
        self.verticalLayout.addLayout(self.horizontalLayout_10)
        self.verticalLayout_2.addWidget(self.groupBox)

        self.retranslateUi(SignalDetails)
        QtCore.QMetaObject.connectSlotsByName(SignalDetails)

    def retranslateUi(self, SignalDetails):
        SignalDetails.setWindowTitle(
            QtWidgets.QApplication.translate("SignalDetails", "SignalDetails", None, -1)
        )
        self.groupBox.setTitle(
            QtWidgets.QApplication.translate("SignalDetails", "Signal", None, -1)
        )
        self.nameLabel.setText(
            QtWidgets.QApplication.translate("SignalDetails", "name", None, -1)
        )
        self.commentLabel.setText(
            QtWidgets.QApplication.translate("SignalDetails", "comment", None, -1)
        )
        self.startLabel.setText(
            QtWidgets.QApplication.translate("SignalDetails", "start", None, -1)
        )
        self.lengthLabel.setText(
            QtWidgets.QApplication.translate("SignalDetails", "length", None, -1)
        )
        self.typeLabel.setText(
            QtWidgets.QApplication.translate("SignalDetails", "type", None, -1)
        )
        self.unitLabel.setText(
            QtWidgets.QApplication.translate("SignalDetails", "unit", None, -1)
        )
        self.minValueLabel.setText(
            QtWidgets.QApplication.translate("SignalDetails", "min_value", None, -1)
        )
        self.maxValueLabel.setText(
            QtWidgets.QApplication.translate("SignalDetails", "max_value", None, -1)
        )
        self.muxLabel.setText(
            QtWidgets.QApplication.translate("SignalDetails", "mux", None, -1)
        )
        self.muxCountLabel.setText(
            QtWidgets.QApplication.translate("SignalDetails", "mux_count", None, -1)
        )
        self.byteOrderLabel.setText(
            QtWidgets.QApplication.translate("SignalDetails", "byte_order", None, -1)
        )
        self.scaleLabel.setText(
            QtWidgets.QApplication.translate("SignalDetails", "scale", None, -1)
        )
        self.offsetLabel.setText(
            QtWidgets.QApplication.translate("SignalDetails", "offset", None, -1)
        )
        self.saveSignal.setText(
            QtWidgets.QApplication.translate("SignalDetails", "Save", None, -1)
        )
        self.signalDeleteButton.setText(
            QtWidgets.QApplication.translate("SignalDetails", "Delete", None, -1)
        )
